@@ -6,12 +6,12 @@
 // Includes ====================================================================
 #include <Magick++/Drawable.h>
 
-// Using =======================================================================
-using namespace boost::python;
-
 // Declarations ================================================================
 #include <Magick++.h>
 
+// Using =======================================================================
+using namespace boost::python;
+
 namespace  {
 
 struct Magick_DrawableDashArray_Wrapper: Magick::DrawableDashArray
@@ -19,7 +19,7 @@ struct Magick_DrawableDashArray_Wrapper: Magick::DrawableDashArray
     Magick_DrawableDashArray_Wrapper(PyObject* py_self_, const double* p0):
         Magick::DrawableDashArray(p0), py_self(py_self_) {}
 
-    Magick_DrawableDashArray_Wrapper(PyObject* py_self_, const unsigned int* p0):
+    Magick_DrawableDashArray_Wrapper(PyObject* py_self_, const size_t* p0):
         Magick::DrawableDashArray(p0), py_self(py_self_) {}
 
     Magick_DrawableDashArray_Wrapper(PyObject* py_self_, const Magick::DrawableDashArray& p0):
@@ -37,9 +37,9 @@ struct Magick_DrawableDashArray_Wrapper: Magick::DrawableDashArray
 void Export_pyste_src_DrawableDashArray()
 {
     class_< Magick::DrawableDashArray, Magick_DrawableDashArray_Wrapper >("DrawableDashArray", init< const double* >())
-        .def(init< const unsigned int* >())
+        .def(init< const size_t* >())
         .def(init< const Magick::DrawableDashArray& >())
     ;
-
+implicitly_convertible<Magick::DrawableDashArray,Magick::Drawable>();
 }
 
